<?php

/**
 * Class EkomiIntegrationModuleCenterModuleController.
 *
 * This is a EkomiIntegration overload for the AbstractModuleCenterModuleController.
 *
 * @see AbstractModuleCenterModuleController
 *
 * @extends    AbstractModuleCenterModuleController
 *
 * @category   System
 *
 * @author     eKomi Ltd <support@ekomi.de>
 */
class EkomiIntegrationModuleCenterModuleController extends AbstractModuleCenterModuleController
{
    /**
     * Save button value.
     */
    const ACTION_SAVE = 'save';

    /**
     * Message types.
     */
    const MESSAGE_TYPE_SUCCESS = 'success';
    const MESSAGE_TYPE_ERROR = 'error';

    /**
     * initializes the class properties.
     */
    protected function _init()
    {
        $this->pageTitle = $this->languageTextManager->get_text('ekomiIntegration_title');
        $this->contentView->set_template_dir(DIR_FS_CATALOG . 'user_classes/modules/ekomiIntegration/templates/');
    }

    /**
     * Accepts the default actions.
     */
    public function actionDefault()
    {
        $action = xtc_href_link('admin.php', 'do=' . $_GET['do'] . '&action=save');
        if (isset($_GET['action']) && self::ACTION_SAVE == $_GET['action']) {
            $message = $this->_save();
            xtc_redirect(xtc_href_link('admin.php', 'do=' . $_GET['do']));
        } else {
            $message = $_SESSION['flashMessage'];
            $messageType = $_SESSION['messageType'];
            $_SESSION['flashMessage'] = '';
            $_SESSION['messageType'] = '';
        }

        $orderStatuses = xtc_get_orders_status();
        $templateData = array(
            'lang' => $this->languageTextManager,
            'message' => $message,
            'messageType' => $messageType,
            'orderStatuses' => $orderStatuses,
            'actionLink' => $action,
            'hiddenToken' => xtc_draw_hidden_field('page_token', $_SESSION['coo_page_token']->generate_token()),
        );

        $content = $this->_render('ekomiIntegration_configuration.html', $templateData);

        return new AdminPageHttpControllerResponse($this->pageTitle, $content, $this->_getAssets());
    }

    /**
     * Gets Assests.
     *
     * @return \AssetCollection|bool
     */
    protected function _getAssets()
    {
        $assets = MainFactory::create('AssetCollection');
        $assets->add(MainFactory::create('Asset', DIR_FS_CATALOG . 'GXModules/Ekomi/EkomiIntegration/Admin/Javascript/extenders/ekomiIntegration.js'));

        return $assets;
    }

    /**
     * Saves or updates the configuration settings.
     *
     * @return string The message either saved or not
     */
    protected function _save()
    {
        if ($_SESSION['coo_page_token']->is_valid($_POST['page_token'])) {
            if (!empty($_POST['shopId']) && isset($_POST['shopPassword'])) {
                $shopId = (int) (trim($_POST['shopId']));
                $shopPassword = gm_prepare_string(trim($_POST['shopPassword']));
                $ekomiIntegrationManager = MainFactory::create_object('EkomiIntegrationManager', array($shopId, $shopPassword));
                if ($ekomiIntegrationManager->verifyAccount()) {
                    $this->saveConfigurations($_POST);
                    if ('1' == gm_prepare_string(trim($_POST['useDefaultPrcWidget']))) {
                        $widgetToken = $ekomiIntegrationManager->getDefaultWidgetToken();
                        $this->saveWidgetToken($widgetToken);
                    }

                    $_SESSION['flashMessage'] = $this->languageTextManager->get_text('ekomiIntegration_config_saved');
                    $_SESSION['messageType'] = self::MESSAGE_TYPE_SUCCESS;
                } else {
                    $this->setDefaults();
                    $_SESSION['flashMessage'] = $this->languageTextManager->get_text('ekomiIntegration_config_invalid');
                    $_SESSION['messageType'] = self::MESSAGE_TYPE_ERROR;
                }
            } else {
                $_SESSION['flashMessage'] = $this->languageTextManager->get_text('ekomiIntegration_config_required');
                $_SESSION['messageType'] = self::MESSAGE_TYPE_ERROR;
            }
        } else {
            $_SESSION['flashMessage'] = $this->languageTextManager->get_text('ekomiIntegration_invalid_token');
            $_SESSION['messageType'] = self::MESSAGE_TYPE_ERROR;
        }
    }

    /**
     * Sets default values.
     */
    protected function setDefaults()
    {
        gm_set_conf('EKOMIINTEGRATION_SHOP_ID', '');
        gm_set_conf('EKOMIINTEGRATION_SHOP_PASSWORD', '');
        gm_set_conf('EKOMIINTEGRATION_ENABLE', '');
    }

    /**
     * Saves default widget token.
     *
     * @param string $widgetToken
     */
    protected function saveWidgetToken($widgetToken)
    {
        gm_set_conf('EKOMIINTEGRATION_PRC_WIDGET_TOKEN', gm_prepare_string($widgetToken));
    }

    /**
     * Saves configurations.
     *
     * @param array $postData
     */
    protected function saveConfigurations($postData)
    {
        $statuses = $postData['orderStatuses'];
        if (!empty($statuses)) {
            $statuses = implode(',', $statuses);
        }

        gm_set_conf('EKOMIINTEGRATION_ORDER_STATUSES', $statuses);
        gm_set_conf('EKOMIINTEGRATION_SHOP_ID', (int) (trim($postData['shopId'])));
        gm_set_conf('EKOMIINTEGRATION_SHOP_PASSWORD', gm_prepare_string(trim($postData['shopPassword'])));
        gm_set_conf('EKOMIINTEGRATION_PRODUCT_REVIEWS', gm_prepare_string(trim($postData['productReviews'])));
        gm_set_conf('EKOMIINTEGRATION_REVIEW_MOD', gm_prepare_string(trim($postData['reviewMod'])));
        gm_set_conf('EKOMIINTEGRATION_PRODUCT_IDENTIFIER', gm_prepare_string(trim($postData['productIdentifier'])));
        gm_set_conf('EKOMIINTEGRATION_EXCLUDE_PRODUCTS', gm_prepare_string(trim($postData['excludeProducts'])));
        gm_set_conf('EKOMIINTEGRATION_SHOW_PRC_WIDGET', gm_prepare_string(trim($postData['showPrcWidget'])));
        gm_set_conf('EKOMIINTEGRATION_USE_DEFAULT_PRC_WIDGET', gm_prepare_string(trim($postData['useDefaultPrcWidget'])));
        gm_set_conf('EKOMIINTEGRATION_PRC_WIDGET_TOKEN', gm_prepare_string(trim($postData['prcWidgetToken'])));
        gm_set_conf('EKOMIINTEGRATION_ENABLE_PRC_WIDGET_TAB', gm_prepare_string(trim($postData['enablePrcWidgetTab'])));
        gm_set_conf('EKOMIINTEGRATION_ENABLE', gm_prepare_string(trim($postData['enable'])));
        gm_set_conf('EKOMIINTEGRATION_TERMS_AND_CONDITIONS', gm_prepare_string(trim($postData['enableTermsAndConditions'])));
    }
}
