<?php

/**
 * Class EkomiIntegrationOrder.
 *
 * Handles the order related functionalities.
 *
 * @category   System
 *
 * @author     eKomi Ltd <support@ekomi.de>
 */
class EkomiIntegrationOrder
{
    /**
     * Plugin name in Plugins-Dashboard.
     */
    const PLUGIN_NAME = 'gambio';

    public $order = null;

    /**
     * Initializes the order object.
     *
     * @param int $orderId The order id
     */
    public function __construct($orderId)
    {
        $this->order = $this->_fetchOrder($orderId);
    }

    /**
     * Gets the order status.
     *
     * @return int order status id Otherwise null
     */
    public function getOrderStatus()
    {
        if (isset($this->order['orders_status'])) {
            return $this->order['orders_status'];
        }

        return null;
    }

    /**
     * Sets the order status.
     *
     * @param int $orderStatus The order status
     */
    public function setOrderStatus($orderStatus)
    {
        if (isset($this->order['orders_status'])) {
            $this->order['orders_status'] = $orderStatus;
        }
    }

    /**
     * Gets the order data.
     *
     * @param int    $shopId
     * @param string $shopPassword
     *
     * @return string The parameters
     */
    public function getOrderData($shopId, $shopPassword)
    {
        unset($this->order['gm_order_html']);
        unset($this->order['gm_order_txt']);
        $orderData = array(
            'order' => $this->order,
            'shop_name' => $this->getStoreName(),
            'shop_email' => $this->getStoreEmail(),
            'products' => $this->getProductsData(),
        );
        $fields = array(
            'shop_id' => $shopId,
            'interface_password' => $shopPassword,
            'order_data' => $orderData,
            'mode' => gm_get_conf('EKOMIINTEGRATION_REVIEW_MOD'),
            'product_reviews' => gm_get_conf('EKOMIINTEGRATION_PRODUCT_REVIEWS'),
            'product_identifier' => gm_get_conf('EKOMIINTEGRATION_PRODUCT_IDENTIFIER'),
            'exclude_products' => gm_get_conf('EKOMIINTEGRATION_EXCLUDE_PRODUCTS'),
            'plugin_name' => self::PLUGIN_NAME,
        );

        return $fields;
    }

    /**
     * Gets the products data.
     *
     * @return array The products array
     */
    protected function getProductsData()
    {
        $orderProducts = $this->_fetchOrderProducts($this->order['orders_id'], $_SESSION['languages_id']);
        require_once DIR_FS_DOCUMENT_ROOT . 'includes/configure.php';
        foreach ($orderProducts as $key => $product) {
            $productId = $product['products_id'];
            $product['image_url'] = $this->_getImage($product['products_image']);
            $product['canonical_url'] = $this->_getProductUrl(
                $productId,
                $product['gm_url_keywords']
            );
            $orderProducts[$key] = $product;
        }

        return $orderProducts;
    }

    /**
     * Gets store name.
     *
     * @return string
     */
    public function getStoreName()
    {
        return STORE_NAME;
    }

    /**
     * Gets store email.
     *
     * @return string
     */
    public function getStoreEmail()
    {
        return STORE_OWNER_EMAIL_ADDRESS;
    }

    /**
     * Fetches order from database.
     *
     * @param int $orderId
     *
     * @return array
     */
    protected function _fetchOrder($orderId)
    {
        $sql = 'SELECT * FROM ' . TABLE_ORDERS . " WHERE orders_id = '{$orderId}'";
        $query = xtc_db_query($sql);
        $oderData = xtc_db_fetch_array($query);

        return $oderData;
    }

    /**
     * Fetches the ordered products.
     *
     * @param int    $orderId    The order id
     * @param string $languageId The order id
     *
     * @return array The products data
     */
    protected function _fetchOrderProducts($orderId, $languageId)
    {
        $sql = 'SELECT pd.gm_url_keywords, p.products_image ,op.* FROM orders_products op'
            . ' INNER JOIN products p on p.products_id = op.products_id'
            . ' INNER JOIN products_description pd on pd.products_id = op.products_id'
            . " WHERE op.orders_id = {$orderId} and pd.language_id = {$languageId}";

        $orderProductsData = xtc_db_query($sql);
        $products = array();
        while ($product = xtc_db_fetch_array($orderProductsData)) {
            $products[] = $product;
        }

        return $products;
    }

    /**
     * Gets the product image.
     *
     * @param string $productImage
     *
     * @return string The images name Otherwise empty
     */
    protected function _getImage($productImage)
    {
        $imageUrl = HTTP_SERVER . DIR_WS_CATALOG . DIR_WS_ORIGINAL_IMAGES
            . $productImage;

        return $imageUrl;
    }

    /**
     * Gets the product Url.
     *
     * @param int    $productId
     * @param string $gmUrlKeyword
     *
     * @return string The product url Otherwise empty
     */
    protected function _getProductUrl($productId, $gmUrlKeyword)
    {
        $canonicalUrl = HTTP_SERVER . DIR_WS_CATALOG . 'product_info.php?info='
            . "p{$productId}_{$gmUrlKeyword}.html";

        return $canonicalUrl;
    }
}
