<?php

/**
 * Class ProductViewOverload.
 *
 * This sample demonstrates the overloading of the ProductInfoContentView class. After enabling this class navigate
 * to a product details page in shop frontend. The quantity units description will be slightly different.
 *
 * @see ProductInfoContentView
 *
 * @extends    EkomiIntegrationProductInfoContentView_parent
 *
 * @category   System
 *
 * @author     eKomi Ltd <support@ekomi.de>
 */
class EkomiIntegrationProductInfoContentView extends EkomiIntegrationProductInfoContentView_parent
{
    const TEMPLATE_PATH = DIR_FS_CATALOG . 'user_classes/modules/ekomiIntegration/templates/';

    /**
     * Overloads prepare_data of the product info content view.
     */
    public function prepare_data()
    {
        parent::prepare_data();
        if (EkomiIntegrationManager::ENABLE_VALUE == gm_get_conf('MODULE_CENTER_EKOMIINTEGRATION_INSTALLED') &&
            EkomiIntegrationManager::ENABLE_VALUE == gm_get_conf('EKOMIINTEGRATION_ENABLE') &&
            EkomiIntegrationManager::ENABLE_VALUE == gm_get_conf('EKOMIINTEGRATION_SHOW_PRC_WIDGET') &&
            !empty(gm_get_conf('EKOMIINTEGRATION_PRC_WIDGET_TOKEN'))
        ) {
            $ekomiSmarPrcWidget = $this->_getSmartWidget();
            $this->set_content_data('ekomi_smart_prc_widget', $ekomiSmarPrcWidget);
            if (EkomiIntegrationManager::ENABLE_VALUE == gm_get_conf('EKOMIINTEGRATION_ENABLE_PRC_WIDGET_TAB')) {
                $this->content_array['tabs'][] = ['title' => 'eKomi Reviews', 'content' => $ekomiSmarPrcWidget];
            }
        }
    }

    /**
     * Gets product identifier.
     *
     * @return int|string
     */
    protected function _getProductIdentifier()
    {
        switch (gm_get_conf('EKOMIINTEGRATION_PRODUCT_IDENTIFIER')) {
            case  EkomiIntegrationManager::PRODUCT_IDENTIFIER_SKU:
                $identifier = $this->content_array['PRODUCTS_MODEL'];
                break;
            default:
                $identifier = $this->content_array['PRODUCTS_ID'];
        }

        return $identifier;
    }

    /**
     * Gets Smart Widget content.
     *
     * @return string
     */
    protected function _getSmartWidget()
    {
        $contentView = MainFactory::create('ContentView');
        $contentView->set_template_dir(self::TEMPLATE_PATH);
        $contentView->set_content_template('smart_prc.html');
        $contentView->set_flat_assigns(true);
        $contentView->set_caching_enabled(false);
        $contentView->set_content_data('customerId', gm_get_conf('EKOMIINTEGRATION_SHOP_ID'));
        $contentView->set_content_data('widgetToken', gm_get_conf('EKOMIINTEGRATION_PRC_WIDGET_TOKEN'));
        $contentView->set_content_data('productIdentifier', $this->_getProductIdentifier());

        return $contentView->get_html();
    }
}
